@@ -1,12 +1,12 @@
 package Sah::Schema::dns::zone;
 
-our $DATE = '2019-07-24'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2019-07-25'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 our $schema = [hash => {
     summary => 'DNS zone structure',
     keys => {
-        records => ["dns::records", {req=>1}, {}],
+        records => ["dns::records_of_known_types", {req=>1}, {}],
     },
     req_keys => [qw/records/],
 }, {}];
@@ -26,7 +26,7 @@ Sah::Schema::dns::zone - DNS zone structure
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::dns::zone (from Perl distribution Sah-Schemas-DNS), released on 2019-07-24.
+This document describes version 0.002 of Sah::Schema::dns::zone (from Perl distribution Sah-Schemas-DNS), released on 2019-07-25.
 
 =head1 HOMEPAGE
 
